@@ -19,7 +19,9 @@
 #ifndef PWMDEDIT_H
 #define PWMDEDIT_H
 
+#include <QSystemTrayIcon>
 #include "pwmdDialog.h"
+#include "pwmdShortcutDialog.h"
 
 class PwmdEdit : public QApplication
 {
@@ -29,9 +31,18 @@ class PwmdEdit : public QApplication
 	PwmdEdit(int argc, char **argv);
 	~PwmdEdit() {};
 
+    private slots:
+	void slotSystemTrayActivated(QSystemTrayIcon::ActivationReason);
+	void slotEditPwmd();
+	void slotEditShortcuts();
+	void slotShortCut(QAction *);
+	void slotClearClipboard();
+
     private:
 	QString filename;
 	QString socket;
+	QSystemTrayIcon *sti;
+	int clipboardTimeout;
 };
 
 #endif
